[% eliza = application.eliza %]
<html>
<head><title>Eliza</title></head>
<body>
<h1>Eliza</h1>

You said: [% eliza.input %]<br>
Eliza responds: [% eliza.output %]<p>

<form method="POST">
What will you say? <input type="text" name="input" size="30"> 
</form>

</body>
</html>
